@@ -49,7 +49,10 @@
 
 package com.openexchange.caldav.mixins;
 
+import static com.openexchange.dav.DAVTools.getExternalPath;
 import com.openexchange.caldav.CaldavProtocol;
+import com.openexchange.config.cascade.ConfigViewFactory;
+import com.openexchange.server.ServiceLookup;
 import com.openexchange.webdav.protocol.helpers.SingleXMLPropertyMixin;
 
 /**
@@ -66,14 +69,17 @@ import com.openexchange.webdav.protocol.helpers.SingleXMLPropertyMixin;
 public class ScheduleInboxURL extends SingleXMLPropertyMixin {
 
 	public static final String SCHEDULE_INBOX = "schedule-inbox";
+	
+	private final ServiceLookup serviceLookup;
 
-    public ScheduleInboxURL() {
+    public ScheduleInboxURL(ServiceLookup serviceLookup) {
         super(CaldavProtocol.CAL_NS.getURI(), "schedule-inbox-URL");
+        this.serviceLookup = serviceLookup;
     }
 
     @Override
     protected String getValue() {
-        return "<D:href>/caldav/" + SCHEDULE_INBOX + "</D:href>";
+        return "<D:href>" + getExternalPath(serviceLookup.getService(ConfigViewFactory.class), "/caldav/" + SCHEDULE_INBOX) + "</D:href>";
     }
 
 }
