@@ -53,12 +53,14 @@ import static com.openexchange.dav.DAVTools.getExternalPath;
 import static com.openexchange.dav.DAVTools.getInternalPath;
 import org.osgi.service.http.HttpService;
 import org.slf4j.Logger;
+import com.openexchange.capabilities.CapabilityService;
 import com.openexchange.capabilities.CapabilitySet;
 import com.openexchange.carddav.Tools;
 import com.openexchange.carddav.photos.PhotoPerformer;
 import com.openexchange.carddav.servlet.CardDAV;
 import com.openexchange.carddav.servlet.CarddavPerformer;
 import com.openexchange.config.cascade.ConfigViewFactory;
+import com.openexchange.config.lean.LeanConfigurationService;
 import com.openexchange.contact.ContactService;
 import com.openexchange.contact.similarity.ContactSimilarityService;
 import com.openexchange.contact.vcard.VCardService;
@@ -99,7 +101,7 @@ public class CarddavActivator extends HousekeepingActivator {
     protected Class<?>[] getNeededServices() {
         return new Class[] {
             HttpService.class, FolderService.class, ConfigViewFactory.class, UserService.class, ContactService.class,
-            ResourceService.class, VCardService.class, GroupService.class
+            ResourceService.class, VCardService.class, GroupService.class, CapabilityService.class, LeanConfigurationService.class
         };
     }
 
