@@ -54,11 +54,12 @@ import java.util.Arrays;
 import java.util.List;
 import com.openexchange.chronos.ResourceId;
 import com.openexchange.chronos.common.CalendarUtils;
+import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.dav.DAVProtocol;
 import com.openexchange.group.Group;
-import com.openexchange.groupware.ldap.User;
 import com.openexchange.java.Strings;
 import com.openexchange.resource.Resource;
+import com.openexchange.user.User;
 import com.openexchange.webdav.protocol.helpers.SingleXMLPropertyMixin;
 
 /**
@@ -75,9 +76,10 @@ public class CalendarUserAddressSet extends SingleXMLPropertyMixin {
      *
      * @param contextID The context identifier
      * @param user The user
+     * @param configViewFactory The configuration view
      */
-    public CalendarUserAddressSet(int contextID, User user) {
-        this(getAddresses(contextID, user));
+    public CalendarUserAddressSet(int contextID, User user, ConfigViewFactory configViewFactory) {
+        this(getAddresses(contextID, user, configViewFactory));
     }
 
     /**
@@ -85,9 +87,10 @@ public class CalendarUserAddressSet extends SingleXMLPropertyMixin {
      *
      * @param contextID The context identifier
      * @param group The group
+     * @param configViewFactory The configuration view
      */
-    public CalendarUserAddressSet(int contextID, Group group) {
-        this(Arrays.asList(PrincipalURL.forGroup(group.getIdentifier()), ResourceId.forGroup(contextID, group.getIdentifier())));
+    public CalendarUserAddressSet(int contextID, Group group, ConfigViewFactory configViewFactory) {
+        this(Arrays.asList(PrincipalURL.forGroup(group.getIdentifier(), configViewFactory), ResourceId.forGroup(contextID, group.getIdentifier())));
     }
 
     /**
@@ -95,12 +98,23 @@ public class CalendarUserAddressSet extends SingleXMLPropertyMixin {
      *
      * @param contextID The context identifier
      * @param resource The resource
+     * @param configViewFactory The configuration view
      */
-    public CalendarUserAddressSet(int contextID, Resource resource) {
-        this(Arrays.asList(PrincipalURL.forResource(resource.getIdentifier()), ResourceId.forResource(contextID, resource.getIdentifier())));
+    public CalendarUserAddressSet(int contextID, Resource resource, ConfigViewFactory configViewFactory) {
+        this(getAddresses(contextID, resource, configViewFactory));
     }
 
-    private static List<String> getAddresses(int contextID, User user) {
+    private static List<String> getAddresses(int contextID, Resource resource, ConfigViewFactory configViewFactory) {
+        List<String> addresses = new ArrayList<String>(3);
+        if (Strings.isNotEmpty(resource.getMail())) {
+            addresses.add(CalendarUtils.getURI(resource.getMail()));
+        }
+        addresses.add(PrincipalURL.forResource(resource.getIdentifier(), configViewFactory));
+        addresses.add(ResourceId.forResource(contextID, resource.getIdentifier()));
+        return addresses;
+    }
+
+    private static List<String> getAddresses(int contextID, User user, ConfigViewFactory configViewFactory) {
         List<String> addresses = new ArrayList<String>(3);
         if (Strings.isNotEmpty(user.getMail())) {
             addresses.add(CalendarUtils.getURI(user.getMail()));
@@ -115,7 +129,7 @@ public class CalendarUserAddressSet extends SingleXMLPropertyMixin {
                 }
             }
         }
-        addresses.add(PrincipalURL.forUser(user.getId()));
+        addresses.add(PrincipalURL.forUser(user.getId(), configViewFactory));
         addresses.add(ResourceId.forUser(contextID, user.getId()));
         return addresses;
     }
